===============
Release History
===============

Release v0.0.2 (2020-02-11)
---------------------------

* Fixed the issue with the wrong paths management.


Initial Release v0.0.1 (2020-02-10)
-----------------------------------

This is the initial release of the package based on the
scientific-python-cookiecutter template. The original code was taken from
https://github.com/mrakitin/extract-pages-script.

Implemented:
************

* Basic tests
* Linux, OSX and Linux builds in TravisCI
* Publishing the documentation
